Reference Files
===============

The ``persistence`` step uses
:ref:`TRAPDENSITY <trapdensity_reffile>`,
:ref:`PERSAT <persat_reffile>`, and
:ref:`TRAPPARS <trappars_reffile>` reference files.

.. include:: ../references_general/trapdensity_reffile.inc

.. include:: ../references_general/persat_reffile.inc

.. include:: ../references_general/trappars_reffile.inc
